% This file produces Figure 2 in Gagliardini, Scaillet (2011). 

 
X = [0.01:0.01:0.99]; % grid of standardized X variable

M1 = 133.19100; % mean of min for education <= 12
S1 =  184.99189; % std dev of min for education <= 12

M2=  166.55195; % mean of min for education > 12
S2=  207.05552; % std dev of min for education > 12

X1 = norminv(X,M1,S1);
X2 = norminv(X,M2,S2);

% import data: estimates and confidence intervalues for X-values in the
% above grid

 % education <= 12, Q-TiR with l=1
 POOR1  = importdata('POOR_E_1.out');
 POOR105  = importdata('POOR_L_1.out');
 POOR195  = importdata('POOR_U_1.out');

 
 % education > 12, Q-TiR with l=1
 WELL1  = importdata('WELL_E_1.out');
 WELL105  = importdata('WELL_L_1.out');
 WELL195  = importdata('WELL_U_1.out');
 
 % education <= 12, Q-TiR with l=2
 POOR2  = importdata('POOR_E_2.out');
 POOR205  = importdata('POOR_L_2.out');
 POOR295  = importdata('POOR_U_2.out');
 
 % education > 12, Q-TiR with l=2
 WELL2  = importdata('WELL_E_2.out');
 WELL205  = importdata('WELL_L_2.out');
 WELL295  = importdata('WELL_U_2.out');
 
 % education <= 12, parametric estimator
 PARAP  = importdata('POOR_P.out');
 
 % education > 12, parametric estimator
 PARAW  = importdata('WELL_P.out');
 
 
 
 

 subplot(2,2,1);
 plot(X1,POOR105,':r',X1,POOR1,'b',X1,POOR195,':r',X1,PARAP,'--g','LineWidth',2);
 xlabel('long-distance calls (in minutes)');
 ylabel('price per minute (in dollars)');
 title('Years of education below or equal to 12');
 set(gca,'ytick',[0 0.05 0.1 0.15 0.20 0.25 ]);
 ylim([0.00 0.26]);
 xlim([0 300]);
 
 subplot(2,2,2);
 plot(X2,WELL105,':r',X2,WELL1,'b',X2,WELL195,':r',X2,PARAW,'--g','LineWidth',2);
 xlabel('long-distance calls (in minutes)');
 ylabel('price per minute (in dollars)');
 title('Years of education above 12');
 ylim([0 0.26]);
 set(gca,'ytick',[0 0.05 0.1 0.15 0.20 0.25 ]);
 xlim([0 300]);
 
 
 subplot(2,2,3);
 plot(X1,POOR205,':r',X1,POOR2,'b',X1,POOR295,':r',X1,PARAP,'--g','LineWidth',2);
 xlabel('long-distance calls (in minutes)');
 ylabel('price per minute (in dollars)');
 title('Years of education below or equal to 12');
 set(gca,'ytick',[0 0.05 0.1 0.15 0.20 0.25]);
 ylim([0.00 0.26]);
 xlim([0 300]);
 
 subplot(2,2,4);
 plot(X2,WELL205,':r',X2,WELL2,'b',X2,WELL295,':r',X2,PARAW,'--g','LineWidth',2);
 xlabel('long-distance calls (in minutes)');
 ylabel('price per minute (in dollars)');
 title('Years of education above 12');
 ylim([0 0.26]);
 set(gca,'ytick',[0 0.05 0.1 0.15 0.20 0.25]);
 xlim([0 300]);
 
 