% This file produces figure 3 in Gagliardini, Scaillet (2011)

X = [0.01:0.01:0.99]; % grid of standardized X variable

M1 = 133.19100; % mean of min for education <= 12
S1 =  184.99189; % std dev of min for education <= 12

M2=  166.55195; % mean of min for education > 12
S2=  207.05552; % std dev of min for education > 12

X1 = norminv(X,M1,S1);
X2 = norminv(X,M2,S2);


% import data: estimates of quartiles and mean regression for X-values in the
% above grid

 % education <= 12 
 POOR25  = importdata('POOR_25.out');
 POOR50  = importdata('POOR_50.out');
 POOR75  = importdata('POOR_75.out');
 POORM  = importdata('POOR_M.out');

 
 % education > 12 
 WELL25  = importdata('WELL_25.out');
 WELL50  = importdata('WELL_50.out');
 WELL75  = importdata('WELL_75.out');
 WELLM  = importdata('WELL_M.out');



 subplot(1,2,1);
 Z = [POOR25,POOR75-POOR25];
 h = area(X1,Z);
 hold on;
 set(h(1),'FaceColor',[1 1 1]);
 set(h(2),'FaceColor',[0.81 0.81 0.81]);
 plot(X1,POOR25,'b',X1,POOR50,'b',X1,POOR75,'b','LineWidth',2);
 hold on;
 plot(X1,POORM,'--black','LineWidth',0.5);
 xlabel('long-distance calls (in minutes)');
 ylabel('price per minute (in dollars)');
 title('Years of education below or equal to 12');
 set(gca,'ytick',[0 0.05 0.10 0.15 0.20 0.25 ]);
 xlim([0 300]);
 ylim([0.0 0.26]);
 
 subplot(1,2,2);
 Z = [WELL25,WELL75-WELL25];
 h = area(X2,Z);
 hold on;
 set(h(1),'FaceColor',[1 1 1]);
 set(h(2),'FaceColor',[0.81 0.81 0.81]);
 plot(X2,WELL25,'b',X2,WELL50,'b',X2,WELL75,'b','LineWidth',2);
 hold on;
 plot(X2,WELLM,'--black','LineWidth',0.5);
 xlabel('long-distance calls (in minutes)');
 ylabel('price per minute (in dollars)');
 title('Years of education above 12');
 set(gca,'ytick',[0 0.05 0.10 0.15 0.20 0.25 ]);
 xlim([0 300]);
 ylim([0.0 0.26]);
 
